To-do list
------

- write should take arguments specifying checkpoint ranges to read.

- check in simple models for testing?

- Gather samyro tweets in a "scrapbook" on trochee.net/samyro/* subpages

- usage examples (notebook? scripting transcript?)

- document creation of an appropriate Anaconda install

- description of future features.

- reader on whole-line data examples

- reader on fixed-length data examples (sonnets?)

- reader that segments and reads Bible verses

- readers that *do* know their length should iterate until stopped?

- build docs into build/docs to support python setup.py upload_docs and
  pythonhosted.org/
